@@ -2,7 +2,19 @@
 
 import string, textwrap
 import numpy as np
-from . import crm, infrared, maps, molar, spectro, vindta, parameterisations, plot
+from . import (
+    airica,
+    crm,
+    infrared,
+    maps,
+    molar,
+    optode,
+    parameterisations,
+    plot,
+    quaatro,
+    spectro,
+    vindta,
+)
 from .vindta import (
     Dbs,
     read_dbs,
@@ -26,11 +38,12 @@ from .vindta import (
     concat,
     poison_correction,
 )
+from .optode import pH_optode
 from .plot import get_cluster_profile, cluster_profile
 from .parameterisations import aou_GG92
 
-__version__ = "0.0.17"
-__author__ = "Humphreys, Matthew P."
+__version__ = "0.0.21"
+__author__ = "Humphreys, Matthew P. and Delaigue, Louise"
 
 
 lcletter = dict(zip(range(1, 27), string.ascii_lowercase))
@@ -42,17 +55,17 @@ def sigfig(x, sf):
     return factor * np.around(x / factor, decimals=sf)
 
 
-def say_hello():
+def hello():
     greeting = textwrap.dedent(
         r"""
         k  Miscellaneous tools for
         o  marine carbonate chemistry
         o  and other such things
         l  
-        s  Matthew P. Humphreys
-        t  https://mvdh.xyz
+        s  Version {}
+        t  doi:10.5281/zenodo.3999292
         o  
-        f  Version {}
+        f  https://humphreys.science
         """.format(
             __version__
         )
@@ -60,4 +73,5 @@ def say_hello():
     print(greeting)
 
 
-hello = say_hello
+# Alias for back-compat
+say_hello = hello
